"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DkBatchGetCommand = void 0;
const lib_dynamodb_1 = require("@aws-sdk/lib-dynamodb");
const Command_1 = require("./Command");
const defaults_1 = require("../util/defaults");
const Middleware_1 = require("../Middleware");
const BATCH_GET_COMMAND_INPUT_DATA_TYPE = 'BatchGetCommandInput';
const BATCH_GET_COMMAND_INPUT_HOOK = ['CommandInput', 'ReadCommandInput', BATCH_GET_COMMAND_INPUT_DATA_TYPE];
const BATCH_GET_COMMAND_OUTPUT_DATA_TYPE = 'BatchGetCommandOutput';
const BATCH_GET_COMMAND_OUTPUT_HOOK = [
    'CommandOutput',
    'ReadCommandOutput',
    BATCH_GET_COMMAND_OUTPUT_DATA_TYPE
];
class DkBatchGetCommand extends Command_1.DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: BATCH_GET_COMMAND_INPUT_DATA_TYPE, hooks: BATCH_GET_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: BATCH_GET_COMMAND_OUTPUT_DATA_TYPE, hooks: BATCH_GET_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = (0, defaults_1.applyDefaults)(this.input, defaults, ['ReturnConsumedCapacity']);
            const { data: postMiddlewareInput } = await (0, Middleware_1.executeMiddlewares)([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            return postMiddlewareInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const typedOutput = output;
            const { data: postMiddlewareOutput } = await (0, Middleware_1.executeMiddlewares)([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: typedOutput
            }, middleware);
            if (postMiddlewareOutput.ConsumedCapacity) {
                for (const ConsumedCapacity of postMiddlewareOutput.ConsumedCapacity) {
                    await (0, Middleware_1.executeMiddleware)('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: ConsumedCapacity }, middleware);
                }
            }
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new lib_dynamodb_1.BatchGetCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
exports.DkBatchGetCommand = DkBatchGetCommand;
