"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DkBatchWriteCommand = void 0;
const lib_dynamodb_1 = require("@aws-sdk/lib-dynamodb");
const Command_1 = require("./Command");
const defaults_1 = require("../util/defaults");
const Middleware_1 = require("../Middleware");
const BATCH_WRITE_COMMAND_INPUT_DATA_TYPE = 'BatchWriteCommandInput';
const BATCH_WRITE_COMMAND_INPUT_HOOK = [
    'CommandInput',
    'WriteCommandInput',
    BATCH_WRITE_COMMAND_INPUT_DATA_TYPE
];
const BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE = 'BatchWriteCommandOutput';
const BATCH_WRITE_COMMAND_OUTPUT_HOOK = [
    'CommandOutput',
    'WriteCommandOutput',
    BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE
];
class DkBatchWriteCommand extends Command_1.DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: BATCH_WRITE_COMMAND_INPUT_DATA_TYPE, hooks: BATCH_WRITE_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE, hooks: BATCH_WRITE_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = (0, defaults_1.applyDefaults)(this.input, defaults, [
                'ReturnConsumedCapacity',
                'ReturnItemCollectionMetrics'
            ]);
            const { data: postMiddlewareInput } = await (0, Middleware_1.executeMiddlewares)([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            return postMiddlewareInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const typedOutput = output;
            const { data: postMiddlewareOutput } = await (0, Middleware_1.executeMiddlewares)([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: typedOutput
            }, middleware);
            if (postMiddlewareOutput.ConsumedCapacity) {
                for (const ConsumedCapacity of postMiddlewareOutput.ConsumedCapacity) {
                    await (0, Middleware_1.executeMiddleware)('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: ConsumedCapacity }, middleware);
                }
            }
            if (postMiddlewareOutput.ItemCollectionMetrics) {
                await (0, Middleware_1.executeMiddleware)('ItemCollectionMetrics', { dataType: 'ItemCollectionMetrics', data: postMiddlewareOutput.ItemCollectionMetrics }, middleware);
            }
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new lib_dynamodb_1.BatchWriteCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
exports.DkBatchWriteCommand = DkBatchWriteCommand;
