"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DkScanCommand = void 0;
const lib_dynamodb_1 = require("@aws-sdk/lib-dynamodb");
const Command_1 = require("./Command");
const defaults_1 = require("../util/defaults");
const Middleware_1 = require("../Middleware");
const SCAN_COMMAND_INPUT_DATA_TYPE = 'ScanCommandInput';
const SCAN_COMMAND_INPUT_HOOK = ['CommandInput', 'ReadCommandInput', SCAN_COMMAND_INPUT_DATA_TYPE];
const SCAN_COMMAND_OUTPUT_DATA_TYPE = 'ScanCommandOutput';
const SCAN_COMMAND_OUTPUT_HOOK = ['CommandOutput', 'ReadCommandOutput', SCAN_COMMAND_OUTPUT_DATA_TYPE];
class DkScanCommand extends Command_1.DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: SCAN_COMMAND_INPUT_DATA_TYPE, hooks: SCAN_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: SCAN_COMMAND_OUTPUT_DATA_TYPE, hooks: SCAN_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = (0, defaults_1.applyDefaults)(this.input, defaults, ['ReturnConsumedCapacity']);
            const { data: postMiddlewareInput } = await (0, Middleware_1.executeMiddlewares)([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            return postMiddlewareInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const typedOutput = output;
            const { data: postMiddlewareOutput } = await (0, Middleware_1.executeMiddlewares)([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: typedOutput
            }, middleware);
            if (postMiddlewareOutput.ConsumedCapacity)
                await (0, Middleware_1.executeMiddleware)('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: postMiddlewareOutput.ConsumedCapacity }, middleware);
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new lib_dynamodb_1.ScanCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
exports.DkScanCommand = DkScanCommand;
