"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.batchGetItems = exports.batchGetTableItems = void 0;
const BatchGet_1 = require("../command/BatchGet");
const batchGetTableItems = async (Table, keys, input, dkClient = Table.dkClient) => {
    const { PageLimit = 100, ReturnConsumedCapacity, ...rest } = input || {};
    if (keys.length === 0)
        return {
            Responses: [],
            UnprocessedKeys: {
                Keys: [],
                ...rest
            }
        };
    const limitedPageLimit = Math.min(PageLimit, 100);
    const recurse = async (remainingKeys) => {
        var _a;
        const currentKeys = remainingKeys.slice(0, limitedPageLimit);
        const output = await dkClient.send(new BatchGet_1.DkBatchGetCommand({
            RequestItems: {
                [Table.name]: {
                    Keys: currentKeys,
                    ...rest
                }
            },
            ReturnConsumedCapacity
        }));
        const nextRemainingKeys = remainingKeys.slice(limitedPageLimit);
        const Responses = output.Responses[Table.name];
        const UnprocessedKeys = output.UnprocessedKeys[Table.name] || { Keys: [] };
        if (nextRemainingKeys.length === 0) {
            return {
                Responses,
                UnprocessedKeys
            };
        }
        const nextPage = await recurse(nextRemainingKeys);
        return {
            Responses: [...Responses, ...nextPage.Responses],
            UnprocessedKeys: {
                Keys: [...UnprocessedKeys.Keys, ...(((_a = nextPage.UnprocessedKeys) === null || _a === void 0 ? void 0 : _a.Keys) || [])],
                ...rest
            }
        };
    };
    return recurse(keys);
};
exports.batchGetTableItems = batchGetTableItems;
const batchGetItems = async (KeySpace, keys, input) => {
    return (0, exports.batchGetTableItems)(KeySpace.Table, keys.map(key => KeySpace.keyOf(key), input), input, KeySpace.dkClient);
};
exports.batchGetItems = batchGetItems;
