"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryItems = exports.queryTableItems = void 0;
const Query_1 = require("../command/Query");
const queryTableItems = async (Table, input, dkClient = Table.dkClient) => {
    const recurse = async (totalCount, pageCursorKey) => {
        const { AutoPage, PageLimit, Limit, ...inputRest } = input;
        const output = await dkClient.send(new Query_1.DkQueryCommand({
            ...inputRest,
            TableName: Table.name,
            ExclusiveStartKey: pageCursorKey,
            Limit: PageLimit
        }));
        const { Items, LastEvaluatedKey, Count = 0, ...rest } = output;
        const newTotalCount = totalCount + Items.length;
        if (!AutoPage || !LastEvaluatedKey || (Limit && newTotalCount >= Limit)) {
            return {
                Items: Items.slice(0, Limit),
                LastEvaluatedKey,
                Count,
                ...rest
            };
        }
        const nextPage = await recurse(newTotalCount, LastEvaluatedKey);
        return {
            Items: [...Items, ...nextPage.Items].slice(0, Limit),
            LastEvaluatedKey: nextPage.LastEvaluatedKey,
            Count: Count + (nextPage.Count || 0),
            ...rest
        };
    };
    return recurse(0, input === null || input === void 0 ? void 0 : input.ExclusiveStartKey);
};
exports.queryTableItems = queryTableItems;
const queryItems = async (KeySpace, input) => {
    const output = await (0, exports.queryTableItems)(KeySpace.Table, input, KeySpace.dkClient);
    return {
        ...output,
        Items: output.Items.map(item => {
            KeySpace.assertAttributesAndKeys(item);
            return KeySpace.omitIndexKeys(item);
        })
    };
};
exports.queryItems = queryItems;
