"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanTableItems = void 0;
const Scan_1 = require("../command/Scan");
const scanTableItems = async (Table, input) => {
    const recurse = async (totalCount, pageCursorKey) => {
        const { AutoPage, PageLimit, Limit, ...inputRest } = input || {};
        const output = await Table.dkClient.send(new Scan_1.DkScanCommand({
            ...inputRest,
            TableName: Table.name,
            ExclusiveStartKey: pageCursorKey,
            Limit: PageLimit
        }));
        const { Items, LastEvaluatedKey, Count = 0, ...rest } = output;
        const newTotalCount = totalCount + Items.length;
        if (!AutoPage || !LastEvaluatedKey || (Limit && newTotalCount >= Limit)) {
            return {
                Items: Items.slice(0, Limit),
                LastEvaluatedKey,
                Count,
                ...rest
            };
        }
        const nextPage = await recurse(newTotalCount, LastEvaluatedKey);
        return {
            Items: [...Items, ...nextPage.Items].slice(0, Limit),
            LastEvaluatedKey: nextPage.LastEvaluatedKey,
            Count: Count + (nextPage.Count || 0),
            ...rest
        };
    };
    return recurse(0, input === null || input === void 0 ? void 0 : input.ExclusiveStartKey);
};
exports.scanTableItems = scanTableItems;
