import { BatchGetCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
const BATCH_GET_COMMAND_INPUT_DATA_TYPE = 'BatchGetCommandInput';
const BATCH_GET_COMMAND_INPUT_HOOK = ['CommandInput', 'ReadCommandInput', BATCH_GET_COMMAND_INPUT_DATA_TYPE];
const BATCH_GET_COMMAND_OUTPUT_DATA_TYPE = 'BatchGetCommandOutput';
const BATCH_GET_COMMAND_OUTPUT_HOOK = [
    'CommandOutput',
    'ReadCommandOutput',
    BATCH_GET_COMMAND_OUTPUT_DATA_TYPE
];
export class DkBatchGetCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: BATCH_GET_COMMAND_INPUT_DATA_TYPE, hooks: BATCH_GET_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: BATCH_GET_COMMAND_OUTPUT_DATA_TYPE, hooks: BATCH_GET_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, ['ReturnConsumedCapacity']);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            return postMiddlewareInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const typedOutput = output;
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: typedOutput
            }, middleware);
            if (postMiddlewareOutput.ConsumedCapacity) {
                for (const ConsumedCapacity of postMiddlewareOutput.ConsumedCapacity) {
                    await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: ConsumedCapacity }, middleware);
                }
            }
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new BatchGetCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
