import { QueryCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
export var DkQueryItemsSort;
(function (DkQueryItemsSort) {
    DkQueryItemsSort["ASCENDING"] = "ascending";
    DkQueryItemsSort["DESCENDING"] = "descending";
})(DkQueryItemsSort || (DkQueryItemsSort = {}));
const QUERY_COMMAND_INPUT_DATA_TYPE = 'QueryCommandInput';
const QUERY_COMMAND_INPUT_HOOK = ['CommandInput', 'ReadCommandInput', QUERY_COMMAND_INPUT_DATA_TYPE];
const QUERY_COMMAND_OUTPUT_DATA_TYPE = 'QueryCommandOutput';
const QUERY_COMMAND_OUTPUT_HOOK = ['CommandOutput', 'ReadCommandOutput', QUERY_COMMAND_OUTPUT_DATA_TYPE];
export class DkQueryCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: QUERY_COMMAND_INPUT_DATA_TYPE, hooks: QUERY_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: QUERY_COMMAND_OUTPUT_DATA_TYPE, hooks: QUERY_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, ['ReturnConsumedCapacity']);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            return postMiddlewareInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const typedOutput = output;
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: typedOutput
            }, middleware);
            if (postMiddlewareOutput.ConsumedCapacity)
                await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: postMiddlewareOutput.ConsumedCapacity }, middleware);
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new QueryCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
