import { TransactWriteCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
const TRANSACT_WRITE_COMMAND_INPUT_DATA_TYPE = 'TransactWriteCommandInput';
const TRANSACT_WRITE_COMMAND_INPUT_HOOK = [
    'CommandInput',
    'WriteCommandInput',
    TRANSACT_WRITE_COMMAND_INPUT_DATA_TYPE
];
const TRANSACT_WRITE_COMMAND_OUTPUT_DATA_TYPE = 'TransactWriteCommandOutput';
const TRANSACT_WRITE_COMMAND_OUTPUT_HOOK = [
    'CommandOutput',
    'WriteCommandOutput',
    TRANSACT_WRITE_COMMAND_OUTPUT_DATA_TYPE
];
export class DkTransactWriteCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = {
            dataType: TRANSACT_WRITE_COMMAND_INPUT_DATA_TYPE,
            hooks: TRANSACT_WRITE_COMMAND_INPUT_HOOK
        };
        this.outputMiddlewareConfig = {
            dataType: TRANSACT_WRITE_COMMAND_OUTPUT_DATA_TYPE,
            hooks: TRANSACT_WRITE_COMMAND_OUTPUT_HOOK
        };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, [
                'ReturnConsumedCapacity',
                'ReturnItemCollectionMetrics'
            ]);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            return postMiddlewareInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: output
            }, middleware);
            if (postMiddlewareOutput.ConsumedCapacity) {
                for (const consumedCapacity of postMiddlewareOutput.ConsumedCapacity) {
                    await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: consumedCapacity }, middleware);
                }
            }
            if (postMiddlewareOutput.ItemCollectionMetrics) {
                await executeMiddleware('ItemCollectionMetrics', { dataType: 'ItemCollectionMetrics', data: postMiddlewareOutput.ItemCollectionMetrics }, middleware);
            }
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new TransactWriteCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
