import { DkBatchGetCommand } from '../command/BatchGet';
export const batchGetTableItems = async (Table, keys, input, dkClient = Table.dkClient) => {
    const { PageLimit = 100, ReturnConsumedCapacity, ...rest } = input || {};
    if (keys.length === 0)
        return {
            Responses: [],
            UnprocessedKeys: {
                Keys: [],
                ...rest
            }
        };
    const limitedPageLimit = Math.min(PageLimit, 100);
    const recurse = async (remainingKeys) => {
        const currentKeys = remainingKeys.slice(0, limitedPageLimit);
        const output = await dkClient.send(new DkBatchGetCommand({
            RequestItems: {
                [Table.name]: {
                    Keys: currentKeys,
                    ...rest
                }
            },
            ReturnConsumedCapacity
        }));
        const nextRemainingKeys = remainingKeys.slice(limitedPageLimit);
        const Responses = output.Responses[Table.name];
        const UnprocessedKeys = output.UnprocessedKeys[Table.name] || { Keys: [] };
        if (nextRemainingKeys.length === 0) {
            return {
                Responses,
                UnprocessedKeys
            };
        }
        const nextPage = await recurse(nextRemainingKeys);
        return {
            Responses: [...Responses, ...nextPage.Responses],
            UnprocessedKeys: {
                Keys: [...UnprocessedKeys.Keys, ...(nextPage.UnprocessedKeys?.Keys || [])],
                ...rest
            }
        };
    };
    return recurse(keys);
};
export const batchGetItems = async (KeySpace, keys, input) => {
    return batchGetTableItems(KeySpace.Table, keys.map(key => KeySpace.keyOf(key), input), input, KeySpace.dkClient);
};
