import { DkBatchWriteCommand } from '../command/BatchWrite';
export const batchWriteTableItems = async (Table, requests, input, dkClient = Table.dkClient) => {
    if (requests.length === 0) {
        return {
            UnprocessedItems: []
        };
    }
    const pageLimit = input?.PageLimit ? Math.min(input.PageLimit, 25) : 25;
    const recurse = async (remainingRequests) => {
        const currentRequests = remainingRequests.slice(0, pageLimit);
        const output = await dkClient.send(new DkBatchWriteCommand({
            ...input,
            RequestItems: {
                [Table.name]: currentRequests
            }
        }));
        const UnprocessedItems = output.UnprocessedItems[Table.name] || [];
        const nextRemainingRequests = remainingRequests.slice(pageLimit);
        if (nextRemainingRequests.length === 0) {
            return {
                ...output,
                UnprocessedItems
            };
        }
        const nextPage = await recurse(nextRemainingRequests);
        return {
            ...output,
            UnprocessedItems: [...UnprocessedItems, ...nextPage.UnprocessedItems]
        };
    };
    return recurse(requests.map(request => {
        if ('Put' in request) {
            return {
                PutRequest: {
                    Item: request.Put
                }
            };
        }
        if ('Delete' in request) {
            return {
                DeleteRequest: {
                    Key: request.Delete
                }
            };
        }
        throw new Error('Invalid request');
    }));
};
export const batchWriteItems = async (KeySpace, requests, input) => batchWriteTableItems(KeySpace.Table, requests.map(request => {
    if ('Put' in request) {
        return { Put: KeySpace.withIndexKeys(request.Put) };
    }
    if ('Delete' in request) {
        return { Delete: KeySpace.keyOf(request.Delete) };
    }
    throw new Error('Invalid request');
}), input, KeySpace.dkClient);
