import { primaryIndex } from '../Table';
import { queryTableItems } from './query';
import { createQueryQuickSort } from '../util/createSortKeyQuery';
export const queryQuickTableItems = async (Table, input, dkClient = Table.dkClient) => {
    const index = input.IndexName || primaryIndex;
    const { HashKeyParams, BeginsWith, GreaterThan, LessThan, ...inputRest } = input;
    const hashKey = Table.config.indexes[index].hash.key;
    const hashValue = HashKeyParams[hashKey];
    const sortKey = Table.config.indexes[index].sort?.key;
    const sortParams = createQueryQuickSort(sortKey, { BeginsWith, GreaterThan, LessThan });
    const output = await queryTableItems(Table, {
        ...inputRest,
        KeyConditionExpression: `${hashKey} = :hashValue ${sortParams.KeyConditionExpression || ''}`,
        ExpressionAttributeValues: {
            [`:hashValue`]: hashValue,
            ...sortParams.ExpressionAttributeValues,
            ...input.ExpressionAttributeValues
        }
    }, dkClient);
    return output;
};
export const queryQuickItems = async (KeySpace, input) => {
    const index = input.IndexName || primaryIndex;
    const hashKeyValue = KeySpace.indexAttributeValue(index, KeySpace.Table.config.indexes[index].hash.key, input.HashKeyParams);
    const HashKeyParams = {
        [KeySpace.Table.config.indexes[index].hash.key]: hashKeyValue
    };
    const output = await queryQuickTableItems(KeySpace.Table, { ...input, HashKeyParams }, KeySpace.dkClient);
    return {
        ...output,
        items: output.Items.map(item => {
            KeySpace.assertAttributesAndKeys(item);
            return KeySpace.omitIndexKeys(item);
        })
    };
};
