import { DkOp } from '../UpdateOp';
import { randomString } from './utils';
const createUpdateExpressionPart = (alias, key, value, precedingKeys) => ({
    UpdateExpression: `${precedingKeys ? `${precedingKeys.map(key => `#${key}`).join('.')}.` : ''}#${alias} = :${alias}, `,
    ExpressionAttributeNames: {
        [`#${alias}`]: key
    },
    ExpressionAttributeValues: {
        [`:${alias}`]: value
    }
});
export const createUpdateExpressionParts = (attributes, precedingKeys) => {
    return Object.entries(attributes).flatMap(entry => {
        const [key, value] = entry;
        const alias = randomString(10);
        if (value instanceof DkOp) {
            const updateExpressionPart = value.createUpdateExpressionPart({ key, alias, precedingKeys });
            return [updateExpressionPart];
        }
        if (value !== null && typeof value === 'object' && !Array.isArray(value)) {
            const updateExpressionPrecedingKeyPart = {
                UpdateExpression: '',
                ExpressionAttributeNames: {
                    [`#${alias}`]: key
                },
                ExpressionAttributeValues: {}
            };
            return [
                updateExpressionPrecedingKeyPart,
                ...createUpdateExpressionParts(value, precedingKeys ? [...precedingKeys, alias] : [alias])
            ];
        }
        const updateExpressionPart = createUpdateExpressionPart(alias, key, value, precedingKeys);
        return [updateExpressionPart];
    });
};
export const mergeUpdateExpressionParts = (parts) => parts.reduce((accumulator, expressionPart) => {
    return {
        UpdateExpression: (accumulator.UpdateExpression || '') + expressionPart.UpdateExpression,
        ExpressionAttributeNames: {
            ...accumulator.ExpressionAttributeNames,
            ...expressionPart.ExpressionAttributeNames
        },
        ExpressionAttributeValues: {
            ...accumulator.ExpressionAttributeValues,
            ...expressionPart.ExpressionAttributeValues
        }
    };
}, {
    UpdateExpression: '',
    ExpressionAttributeNames: {},
    ExpressionAttributeValues: {}
});
export const convertObjectToUpdateExpression = (attributes) => {
    const parts = createUpdateExpressionParts(attributes);
    if (parts.length === 0)
        throw new Error('Invalid update object');
    const merged = mergeUpdateExpressionParts(parts);
    const updateExpression = {
        ...merged,
        UpdateExpression: `SET ${merged.UpdateExpression.trim().slice(0, -1)}`
    };
    return updateExpression;
};
