export const dkSetAttributeOnWriteMiddleware = (key, setter) => {
    const batchWriteHandler = {
        hook: 'BatchWriteCommandInput',
        handler: ({ data: batchWriteCommandInput }) => {
            return {
                ...batchWriteCommandInput,
                RequestItems: Object.fromEntries(Object.entries(batchWriteCommandInput.RequestItems).map(([tableName, RequestItems]) => [
                    tableName,
                    RequestItems.map(request => {
                        if ('PutRequest' in request) {
                            return {
                                PutRequest: {
                                    ...request.PutRequest,
                                    Item: {
                                        ...request.PutRequest.Item,
                                        [key]: setter()
                                    }
                                }
                            };
                        }
                        return request;
                    })
                ]))
            };
        }
    };
    const putHandler = {
        hook: 'PutCommandInput',
        handler: ({ data: putCommandInput }) => {
            return {
                ...putCommandInput,
                Item: {
                    ...putCommandInput.Item,
                    [key]: setter()
                }
            };
        }
    };
    const transactWriteHandler = {
        hook: 'TransactWriteCommandInput',
        handler: ({ data: transactWriteCommandInput }) => {
            return {
                ...transactWriteCommandInput,
                TransactItems: transactWriteCommandInput.TransactItems.map(request => {
                    return Object.fromEntries(Object.entries(request).map(([key, value]) => {
                        if (key === 'Put') {
                            return [
                                key,
                                value
                                    ? {
                                        ...value,
                                        Item: {
                                            ...value.Item,
                                            [key]: setter()
                                        }
                                    }
                                    : value
                            ];
                        }
                        if (key === 'Update') {
                            if (!value.UpdateExpression?.startsWith('SET'))
                                return [key, value];
                            return [
                                key,
                                value
                                    ? {
                                        ...value,
                                        UpdateExpression: value.UpdateExpression + `, ${key} = :${key}`,
                                        ExpressionAttributeValues: {
                                            ...value.ExpressionAttributeValues,
                                            [`:${key}`]: setter()
                                        }
                                    }
                                    : value
                            ];
                        }
                        return [key, value];
                    }));
                })
            };
        }
    };
    const updateHandler = {
        hook: 'UpdateCommandInput',
        handler: ({ data: updateCommandInput }) => {
            if (!updateCommandInput.UpdateExpression?.startsWith('SET'))
                return;
            return {
                ...updateCommandInput,
                UpdateExpression: updateCommandInput.UpdateExpression + `, ${key} = :${key}`,
                ExpressionAttributeValues: {
                    ...updateCommandInput.ExpressionAttributeValues,
                    [`:${key}`]: setter()
                }
            };
        }
    };
    return [batchWriteHandler, putHandler, transactWriteHandler, updateHandler];
};
