import { ScanCommandInput, ScanCommandOutput } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { GenericAttributes } from '../util/utils';
import { DkClientConfig } from '../Client';
declare const SCAN_COMMAND_INPUT_DATA_TYPE: "ScanCommandInput";
declare const SCAN_COMMAND_INPUT_HOOK: readonly ["CommandInput", "ReadCommandInput", "ScanCommandInput"];
declare const SCAN_COMMAND_OUTPUT_DATA_TYPE: "ScanCommandOutput";
declare const SCAN_COMMAND_OUTPUT_HOOK: readonly ["CommandOutput", "ReadCommandOutput", "ScanCommandOutput"];
export interface DkScanCommandInput<ExclusiveStartKey extends GenericAttributes = GenericAttributes> extends Omit<ScanCommandInput, 'ExclusiveStartKey' | 'AttributesToGet' | 'ConditionalOperator'> {
    ExclusiveStartKey?: ExclusiveStartKey;
}
export interface DkScanCommandOutput<Attributes extends GenericAttributes = GenericAttributes, LastEvaluatedKey extends GenericAttributes = GenericAttributes> extends Omit<ScanCommandOutput, 'Items' | 'LastEvaluatedKey'> {
    Items: Array<Attributes>;
    LastEvaluatedKey?: LastEvaluatedKey;
}
export declare class DkScanCommand<Attributes extends GenericAttributes = GenericAttributes, CursorKey extends GenericAttributes = GenericAttributes> extends DkCommand<typeof SCAN_COMMAND_INPUT_DATA_TYPE, (typeof SCAN_COMMAND_INPUT_HOOK)[number], DkScanCommandInput<CursorKey>, ScanCommandInput, typeof SCAN_COMMAND_OUTPUT_DATA_TYPE, (typeof SCAN_COMMAND_OUTPUT_HOOK)[number], DkScanCommandOutput<Attributes, CursorKey>, ScanCommandOutput> {
    constructor(input: DkScanCommandInput<CursorKey>);
    inputMiddlewareConfig: {
        dataType: "ScanCommandInput";
        hooks: readonly ["CommandInput", "ReadCommandInput", "ScanCommandInput"];
    };
    outputMiddlewareConfig: {
        dataType: "ScanCommandOutput";
        hooks: readonly ["CommandOutput", "ReadCommandOutput", "ScanCommandOutput"];
    };
    handleInput: ({ defaults, middleware }: DkClientConfig) => Promise<ScanCommandInput>;
    handleOutput: (output: ScanCommandOutput, { middleware }: DkClientConfig) => Promise<DkScanCommandOutput<Attributes, CursorKey>>;
    send: (clientConfig: DkClientConfig) => Promise<DkScanCommandOutput<Attributes, CursorKey>>;
}
export {};
